@@ -113,7 +113,7 @@ class _ShortCutLSTMBaseNeuralNet(torch.nn.Module):
         torch.Tensor
            Outputs prediction.
         """
-        return self(X).detach()
+        return self(X,X_shortcut).detach()
 
     def set_data(self, X, X_shortcut, y, x_type=None, y_type=None):
         """ Set data inputs and outputs.
@@ -324,7 +324,7 @@ class RollMultiLayerShortCutLSTM(MultiLayerShortCutLSTM, roller._RollingBasis):
         _RollingBasis
             The rolling basis model.
         """
-        return roller._RollingBasis.set_roll_period(
+        return roller._ShortCutRollingBasis.set_roll_period(
             self, train_period=train_period, test_period=test_period,
             start=start, end=end, repass_steps=repass_steps
         )
